==> aws-cdk-lib-2.20.0-sources.jar: software/amazon/awscdk/services/secretsmanager/SecretStringValueBeta1.java <==
package software.amazon.awscdk.services.secretsmanager;

/**
 * An experimental class used to specify an initial secret value for a Secret.
 * <p>
 * The class wraps a simple string (or JSON representation) in order to provide some safety checks and warnings
 * about the dangers of using plaintext strings as initial secret seed values via CDK/CloudFormation.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // Creates a new IAM user, access and secret keys, and stores the secret access key in a Secret.
 * User user = new User(this, "User");
 * AccessKey accessKey = AccessKey.Builder.create(this, "AccessKey").user(user).build();
 * SecretStringValueBeta1 secretValue = SecretStringValueBeta1.fromToken(accessKey.secretAccessKey.toString());
 * Secret.Builder.create(this, "Secret")
 *         .secretStringBeta1(secretValue)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.55.1 (build 07d2d90)", date = "2022-04-07T11:16:45.955Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_secretsmanager.SecretStringValueBeta1")
public class SecretStringValueBeta1 extends software.amazon.jsii.JsiiObject {

    protected SecretStringValueBeta1(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SecretStringValueBeta1(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Creates a `SecretValueValueBeta1` from a string value coming from a Token.
     * <p>
     * The intent is to enable creating secrets from references (e.g., <code>Ref</code>, <code>Fn::GetAtt</code>) from other resources.
     * This might be the direct output of another Construct, or the output of a Custom Resource.
     * This method throws if it determines the input is an unsafe plaintext string.
     * <p>
     * For example:
     * <p>
     * <blockquote><pre>
     * // Creates a new IAM user, access and secret keys, and stores the secret access key in a Secret.
     * User user = new User(this, "User");
     * AccessKey accessKey = AccessKey.Builder.create(this, "AccessKey").user(user).build();
     * SecretStringValueBeta1 secretValue = SecretStringValueBeta1.fromToken(accessKey.secretAccessKey.toString());
     * Secret.Builder.create(this, "Secret")
     *         .secretStringBeta1(secretValue)
     *         .build();
     * </pre></blockquote>
     * <p>
     * The secret may also be embedded in a string representation of a JSON structure:
     * const secretValue = secretsmanager.SecretStringValueBeta1.fromToken(JSON.stringify({
     * username: user.userName,
     * database: 'foo',
     * password: accessKey.secretAccessKey.toString(),
     * }));
     * <p>
     * Note that the value being a Token does <em>not</em> guarantee safety. For example, a Lazy-evaluated string
     * (e.g., <code>Lazy.string({ produce: () =&gt; 'myInsecurePassword' }))</code>) is a Token, but as the output is
     * ultimately a plaintext string, and so insecure.
     * <p>
     * @param secretValueFromToken a secret value coming from a Construct attribute or Custom Resource output. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.secretsmanager.SecretStringValueBeta1 fromToken(final @org.jetbrains.annotations.NotNull java.lang.String secretValueFromToken) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.secretsmanager.SecretStringValueBeta1.class, "fromToken", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.SecretStringValueBeta1.class), new Object[] { java.util.Objects.requireNonNull(secretValueFromToken, "secretValueFromToken is required") });
    }

    /**
     * Creates a `SecretStringValueBeta1` from a plaintext value.
     * <p>
     * This approach is inherently unsafe, as the secret value may be visible in your source control repository
     * and will also appear in plaintext in the resulting CloudFormation template, including in the AWS Console or APIs.
     * Usage of this method is discouraged, especially for production workloads.
     * <p>
     * @param secretValue This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.secretsmanager.SecretStringValueBeta1 fromUnsafePlaintext(final @org.jetbrains.annotations.NotNull java.lang.String secretValue) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.secretsmanager.SecretStringValueBeta1.class, "fromUnsafePlaintext", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.SecretStringValueBeta1.class), new Object[] { java.util.Objects.requireNonNull(secretValue, "secretValue is required") });
    }

    /**
     * Returns the secret value.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String secretValue() {
        return software.amazon.jsii.Kernel.call(this, "secretValue", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}

==> aws-cdk-lib-2.35.0-sources.jar: software/amazon/awscdk/services/secretsmanager/SecretStringValueBeta1.java <==
package software.amazon.awscdk.services.secretsmanager;

/**
 * (deprecated) An experimental class used to specify an initial secret value for a Secret.
 * <p>
 * The class wraps a simple string (or JSON representation) in order to provide some safety checks and warnings
 * about the dangers of using plaintext strings as initial secret seed values via CDK/CloudFormation.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * User user = new User(this, "User");
 * AccessKey accessKey = AccessKey.Builder.create(this, "AccessKey").user(user).build();
 * SecretStringValueBeta1 secretValue = SecretStringValueBeta1.fromToken(JSON.stringify(Map.of(
 *         "username", user.getUserName(),
 *         "database", "foo",
 *         "password", accessKey.secretAccessKey.unsafeUnwrap())));
 * </pre></blockquote>
 * <p>
 * @deprecated Use `cdk.SecretValue` instead.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.63.2 (build a8a8833)", date = "2022-08-02T19:52:01.766Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_secretsmanager.SecretStringValueBeta1")
public class SecretStringValueBeta1 extends software.amazon.jsii.JsiiObject {

    protected SecretStringValueBeta1(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SecretStringValueBeta1(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * (deprecated) Creates a `SecretValueValueBeta1` from a string value coming from a Token.
     * <p>
     * The intent is to enable creating secrets from references (e.g., <code>Ref</code>, <code>Fn::GetAtt</code>) from other resources.
     * This might be the direct output of another Construct, or the output of a Custom Resource.
     * This method throws if it determines the input is an unsafe plaintext string.
     * <p>
     * For example:
     * <p>
     * <blockquote><pre>
     * // Creates a new IAM user, access and secret keys, and stores the secret access key in a Secret.
     * User user = new User(this, "User");
     * AccessKey accessKey = AccessKey.Builder.create(this, "AccessKey").user(user).build();
     * Secret secret = Secret.Builder.create(this, "Secret")
     *         .secretStringValue(accessKey.getSecretAccessKey())
     *         .build();
     * </pre></blockquote>
     * <p>
     * The secret may also be embedded in a string representation of a JSON structure:
     * <p>
     * <blockquote><pre>
     * User user = new User(this, "User");
     * AccessKey accessKey = AccessKey.Builder.create(this, "AccessKey").user(user).build();
     * SecretStringValueBeta1 secretValue = SecretStringValueBeta1.fromToken(JSON.stringify(Map.of(
     *         "username", user.getUserName(),
     *         "database", "foo",
     *         "password", accessKey.secretAccessKey.unsafeUnwrap())));
     * </pre></blockquote>
     * <p>
     * Note that the value being a Token does <em>not</em> guarantee safety. For example, a Lazy-evaluated string
     * (e.g., <code>Lazy.string({ produce: () =&gt; 'myInsecurePassword' }))</code>) is a Token, but as the output is
     * ultimately a plaintext string, and so insecure.
     * <p>
     * @param secretValueFromToken a secret value coming from a Construct attribute or Custom Resource output. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.secretsmanager.SecretStringValueBeta1 fromToken(final @org.jetbrains.annotations.NotNull java.lang.String secretValueFromToken) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.secretsmanager.SecretStringValueBeta1.class, "fromToken", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.SecretStringValueBeta1.class), new Object[] { java.util.Objects.requireNonNull(secretValueFromToken, "secretValueFromToken is required") });
    }

    /**
     * (deprecated) Creates a `SecretStringValueBeta1` from a plaintext value.
     * <p>
     * This approach is inherently unsafe, as the secret value may be visible in your source control repository
     * and will also appear in plaintext in the resulting CloudFormation template, including in the AWS Console or APIs.
     * Usage of this method is discouraged, especially for production workloads.
     * <p>
     * @param secretValue This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.secretsmanager.SecretStringValueBeta1 fromUnsafePlaintext(final @org.jetbrains.annotations.NotNull java.lang.String secretValue) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.secretsmanager.SecretStringValueBeta1.class, "fromUnsafePlaintext", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.SecretStringValueBeta1.class), new Object[] { java.util.Objects.requireNonNull(secretValue, "secretValue is required") });
    }

    /**
     * (deprecated) Returns the secret value.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public @org.jetbrains.annotations.NotNull java.lang.String secretValue() {
        return software.amazon.jsii.Kernel.call(this, "secretValue", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}
